@@ -1,6 +1,6 @@
 #![feature(drain_filter)]
 
-use parse::{replace_async_for, AsyncGeneratorExprInput, AsyncGeneratorItemInput};
+use parse::{replace_async_for, AttrGenerator, ExprGenerator};
 use proc_macro::TokenStream as TokenStream1;
 use proc_macro2::TokenStream;
 use quote::ToTokens;
@@ -8,12 +8,11 @@ use syn::parse2;
 
 mod parse;
 mod process;
-mod tokens;
 
 #[proc_macro]
 pub fn async_generator(input: TokenStream1) -> TokenStream1 {
     let input: TokenStream = input.into();
-    let input: AsyncGeneratorExprInput = match parse2(replace_async_for(input)) {
+    let input: ExprGenerator = match parse2(replace_async_for(input)) {
         Ok(input) => input,
         Err(err) => {
             return err.to_compile_error().into();
@@ -30,7 +29,7 @@ pub fn async_generator(input: TokenStream1) -> TokenStream1 {
 pub fn generator(_args: TokenStream1, input: TokenStream1) -> TokenStream1 {
     let input: TokenStream = input.into();
     let input = replace_async_for(input);
-    let input: AsyncGeneratorItemInput = match parse2(input) {
+    let input: AttrGenerator = match parse2(input) {
         Ok(input) => input,
         Err(err) => {
             return err.to_compile_error().into();
